/*
 * oma-ds-agent
 * Copyright (c) 2012 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 *   @Common_Vconf.h
 *   @version									0.1
 *   @brief										This file is the header file of defined vconf value
 */

#ifndef COMMON_VCONF_H_
#define COMMON_VCONF_H_

#include <stdbool.h>

/**
 * @par Description: API to get value(char*) from vconf
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		string type, base key
 * @param[in]		string type, key
 * @param[out]
 *
 * @return				value on success
 *							NULL on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
char *get_vconf_str(char *base_key, char *key);

/**
 * @par Description: API to get value(char*) from vconf
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		string type, key
 * @param[out]
 *
 * @return				value on success
 *							NULL on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
char *get_vconf_str_key(char *key);

/**
 * @par Description: API to get value(int) from vconf
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		string type, base key
 * @param[in]		string type, key
 * @param[out]		int type, value
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool get_vconf_int(char *base_key, char *key, int *value);

/**
 * @par Description: API to get value(int) from vconf
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		string type, key
 * @param[out]		int type, value
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool get_vconf_int_key(char *key, int *value);

/**
 * @par Description: API to set value(char*) into vconf
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		string type, basekey
 * @param[in]		string type, key
 * @param[in]		string type, value
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool set_vconf_str(char *base_key, char *key, char *value);

/**
 * @par Description: API to set value(char*) into vconf
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		string type, key
 * @param[in]		string type, value
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool set_vconf_str_key(char *key, char *value);

/**
 * @par Description: API to set value(int) into vconf
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		string type, basekey
 * @param[in]		string type, key
 * @param[in]		int type, value
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool set_vconf_int(char *base_key, char *key, int value);

/**
 * @par Description: API to set value(int) into vconf
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		string type, key
 * @param[in]		int type, value
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool set_vconf_int_key(char *key, int value);

#endif				/* COMMON_VCONF_H_ */
