/*
 * oma-ds-agent
 * Copyright (c) 2012 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 *   @OMA_DS_Event_Handler.h
 *   @version									0.1
 *   @brief										This file is the header file of interface for event callback function(from UI)
 */

#ifndef OMA_DS_EVENT_HANDLER_H_
#define OMA_DS_EVENT_HANDLER_H_

#include <stdio.h>
#include <sync_agent.h>

/**
 * @par Description: This API is event callback function for add profile
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		buffer for incomming parameter
 * @param[in]		buffer for outgoing parameter
 * @param[out]
 *
 * @return				0 on success
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int event_callback_add_profile_sync(sync_agent_event_data_s * request, sync_agent_event_data_s * response);

/**
 * @par Description: This API is event callback function for edit profile
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		buffer for incomming parameter
 * @param[in]		buffer for outgoing parameter
 * @param[out]
 *
 * @return				0 on success
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int event_callback_edit_profile_sync(sync_agent_event_data_s * request, sync_agent_event_data_s * response);

/**
 * @par Description: This API is event callback function for delete profile
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		buffer for incomming parameter
 * @param[in]		buffer for outgoing parameter
 * @param[out]
 *
 * @return				0 on success
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int event_callback_delete_profile_sync(sync_agent_event_data_s * request, sync_agent_event_data_s * response);

/**
 * @par Description: This API is event callback function for request sync
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		buffer for incomming parameter
 * @param[in]		buffer for outgoing parameter
 * @param[out]
 *
 * @return				0 on success
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int event_callback_request_sync_sync(sync_agent_event_data_s * request, sync_agent_event_data_s * response);

/**
 * @par Description: This API is event callback function for cancel sync
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		buffer for incomming parameter
 * @param[in]		buffer for outgoing parameter
 * @param[out]
 *
 * @return				0 on success
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int event_callback_cancel_sync_sync(sync_agent_event_data_s * request, sync_agent_event_data_s * response);

/**
 * @par Description: This API is event callback function for get profile data
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		buffer for incomming parameter
 * @param[in]		buffer for outgoing parameter
 * @param[out]
 *
 * @return				0 on success
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int event_callback_get_profile_data_sync(sync_agent_event_data_s * request, sync_agent_event_data_s * response);

/**
 * @par Description: This API is event callback function for getting profile sync category
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		buffer for incomming parameter
 * @param[in]		buffer for outgoing parameter
 * @param[out]
 *
 * @return				0 on success
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int event_callback_get_profile_sync_category_sync(sync_agent_event_data_s * request, sync_agent_event_data_s * response);

/**
 * @par Description: This API is event callback function for last statistics
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		buffer for incomming parameter
 * @param[in]		buffer for outgoing parameter
 * @param[out]
 *
 * @return				0 on success
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int event_callback_get_profile_last_statistics_sync(sync_agent_event_data_s * request, sync_agent_event_data_s * response);

/**
 * @par Description: This API is event callback function for add profile for CP
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		buffer for incomming parameter
 * @param[in]		buffer for outgoing parameter
 * @param[out]
 *
 * @return				0 on success
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int event_callback_add_profile_cp_sync(sync_agent_event_data_s * request, sync_agent_event_data_s * response);

/**
 * @par Description: This API is event callback function for request callog sync
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		buffer for incomming parameter
 * @param[in]		buffer for outgoing parameter
 * @param[out]
 *
 * @return				0 on success
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int event_callback_request_calllog_sync_async(sync_agent_event_data_s * request, sync_agent_event_data_s * response);

/**
 * @par Description: This API is event callback function for request reset all data
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		buffer for incomming parameter
 * @param[in]		buffer for outgoing parameter
 * @param[out]
 *
 * @return				0 on success
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int event_callback_request_reset_all_data_sync(sync_agent_event_data_s * request, sync_agent_event_data_s * response);

/**
 * @par Description: This API is event callback function for request reset all data
 *
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		buffer for incomming parameter
 * @param[in]		buffer for outgoing parameter
 * @param[out]
 *
 * @return				0 on success
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
int event_callback_request_get_all_profiles_data(sync_agent_event_data_s * request, sync_agent_event_data_s * response);

#endif				/* OMA_DS_EVENT_HANDLER_H_ */
