/*
 * oma-ds-agent
 * Copyright (c) 2012 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 *   @SA_Error.h
 *   @version									0.1
 *   @brief										This file is the header file of Error is defined
 */

#ifndef SA_ERROR_H_
#define SA_ERROR_H_

typedef enum {
	ERROR_UNKNOWN = 0,

	/* Informational */
	IN_PROGRESS = 101,

	/* OK code */
	/** No error */
	NO_ERROR = 200,
	/** Requested item was added */
	ITEM_ADDED = 201,
	/** Accepted for processing */
	PROCESSING_ACCEPTED = 202,
	/** Non-authoritative response */
	NON_AUTHORITATIVE = 203,
	/** No content */
	NO_CONTENT = 204,
	/** Reset content */
	RESET_CONTENT = 205,
	/** Partial content */
	PARTIAL_CONTENT = 206,
	/** Conflict resolved with merge */
	CONFLICT_MERGE = 207,
	/** Conflict resolved with client win */
	CONFLICT_CLIENT_WIN = 208,
	/** Conflict resolved with duplicate */
	CONFLICT_DUPLICATE = 209,
	/** Deleted without archiving */
	DELETE_NO_ARCHIVE = 210,
	/** Item not deleted (not found) */
	DELETE_NOT_FOUND = 211,
	/** Authentication accepted */
	AUTH_ACCEPTED = 212,
	/** Chunked item accepted */
	CHUNK_ACCEPTED = 213,
	/** Operation cancelled */
	OPERATION_CANCELLED = 214,
	/** Not executed */
	NOT_EXECUTED = 215,
	/** Atomic rollback ok */
	ATOMIC_ROLLBACK_OK = 216,

	/* Retry error */
	ERROR_MULTIPLE_CHOICES = 300,
	ERROR_MOVED_PERMANENTLY = 301,
	ERROR_FOUND_RETRY = 302,
	ERROR_SEE_OTHER_RETRY = 303,
	ERROR_NOT_MODIFIED = 304,
	ERROR_USE_PROXY = 305,

	/* Errors */
	ERROR_BAD_REQUEST = 400,	/* Bad Request */
	ERROR_AUTH_REJECTED = 401,	/* Unauthorized, Invalid Credentials */
	ERROR_PAYMENT_NEEDED = 402,	/* Payment need */
	ERROR_FORBIDDEN = 403,	/* Forbidden */
	ERROR_NOT_FOUND = 404,	/* Not found */
	ERROR_COMMAND_NOT_ALLOWED = 405,	/* Command not allowed */
	ERROR_UNSUPPORTED_FEATURE = 406,	/* Optional feature unsupported */
	ERROR_AUTH_REQUIRED = 407,	/* Authentication required, Missing Credentials */
	ERROR_SIZE_REQUIRED = 411,
	ERROR_REQUESTED_SIZE_TOO_BIG = 416,
	ERROR_RETRY_LATER = 417,	/* Retry later */
	ERROR_ALREADY_EXISTS = 418,	/* Put or Add failed because item already exists */
	ERROR_SIZE_MISMATCH = 424,	/* Size mismatch */

	/* Standard errors */
	ERROR_GENERIC = 500,
	ERROR_NOT_IMPLEMENTED = 501,
	ERROR_SERVICE_UNAVAILABLE = 503,
	ERROR_REQUIRE_REFRESH = 508,
	ERROR_SERVER_FAILURE = 511,

} oma_status_type_e;

typedef enum {

	/* Internal errors - never ever send this via SyncML */
	SA_ERROR_UNKNOWN = 0,
	SA_INTERNAL_OK = 1,
	SA_INTERNAL_ERROR,
	SA_INTERNAL_BINDER_ERROR,
	SA_INTERNAL_TIMEOUT,
	SA_INTERNAL_NOT_FOUND,
	SA_INTERNAL_MISCONFIGURATION,
	SA_INTERNAL_NO_MEMORY,
	SA_INTERNAL_NOT_DEFINED,
	SA_INTERNAL_CONNECTION_ERROR,
	SA_INTERNAL_DA_ERROR,
	SA_INTERNAL_CANCEL,
	SA_INTERNAL_AUTOCONFIG_NOT_SUPPORT_BY_SERVER,
	SA_INTERNAL_BUSY_SIGNALING,
	SA_INTERNAL_SERVER_FAILURE,
	SA_INTERNAL_SERVER_ERROR,
	SA_INTERNAL_AUTHENTICATION_ERROR,
	SA_INTERNAL_SUSPEND_FAIL,
} sa_error_type_e;

#endif				/* SA_ERROR_H_ */
